@@ -1,4 +1,4 @@
-use std::{env, fmt, io, path::PathBuf, sync::Mutex, thread};
+use std::{collections::HashMap, env, fmt, io, path::PathBuf, sync::Mutex, thread};
 
 use lazy_static::lazy_static;
 use serde::{Deserialize, Serialize};
@@ -15,6 +15,7 @@ lazy_static! {
 #[serde(default, rename_all = "lowercase", tag = "type")]
 pub struct Command {
     pub argv: Option<Vec<String>>,
+    pub env: Option<HashMap<String, String>>,
     pub chdir: Option<PathBuf>,
     pub command: String,
     pub creates: Option<PathBuf>,
@@ -24,6 +25,7 @@ impl Default for Command {
     fn default() -> Self {
         Command {
             argv: None,
+            env: None,
             chdir: None,
             command: String::new(),
             creates: None,
@@ -81,9 +83,16 @@ impl Command {
             Some(c) => c.clone(),
             None => env::current_dir().unwrap(),
         };
+        let mut env: Vec<(String, String)> = vec![];
+        if let Some(map) = &self.env {
+            for (key, value) in map {
+                env.push((key.to_string(), value.to_string()));
+            }
+        }
         let mut p = Exec::cmd(&self.command)
             .args(&args)
             .cwd(&cwd)
+            .env_extend(&env)
             .stdout(Redirection::Pipe)
             .stderr(Redirection::Pipe)
             .popen()
