@@ -4,6 +4,7 @@ pub(crate) mod file;
 pub(crate) mod git;
 pub(crate) mod installercargo;
 pub(crate) mod installergo;
+pub(crate) mod installernpm;
 
 use std::{cell::Cell, convert::TryFrom, fmt, time::Instant};
 
@@ -17,6 +18,7 @@ use file::File;
 use git::Git;
 use installercargo::InstallerCargo;
 use installergo::InstallerGo;
+use installernpm::InstallerNpm;
 
 #[derive(Debug, ThisError)]
 pub enum Error {
@@ -51,6 +53,11 @@ pub enum Error {
         source: installergo::Error,
     },
     #[error(transparent)]
+    InstallerNpmJob {
+        #[from]
+        source: installernpm::Error,
+    },
+    #[error(transparent)]
     ParseToml {
         #[from]
         source: toml::de::Error,
@@ -113,6 +120,9 @@ impl Execute for Job {
                 .execute()
                 .map_err(|e| Error::InstallerCargoJob { source: e }),
             Spec::InstallerGo(j) => j.execute().map_err(|e| Error::InstallerGoJob { source: e }),
+            Spec::InstallerNpm(j) => j
+                .execute()
+                .map_err(|e| Error::InstallerNpmJob { source: e }),
         };
         self.history.updated.set(Instant::now());
         result
@@ -166,6 +176,7 @@ pub enum Spec {
     Git(Git),
     InstallerCargo(InstallerCargo),
     InstallerGo(InstallerGo),
+    InstallerNpm(InstallerNpm),
 }
 impl fmt::Display for Spec {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
@@ -176,6 +187,7 @@ impl fmt::Display for Spec {
             Spec::Git(j) => write!(f, "{}", j),
             Spec::InstallerCargo(j) => write!(f, "{}", j),
             Spec::InstallerGo(j) => write!(f, "{}", j),
+            Spec::InstallerNpm(j) => write!(f, "{}", j),
         }
     }
 }
@@ -295,6 +307,7 @@ mod tests {
     use file::FileState;
     use installercargo::DesiredState as DesiredStateCargo;
     use installergo::DesiredState as DesiredStateGo;
+    use installernpm::DesiredState as DesiredStateNpm;
 
     use super::*;
 
@@ -442,12 +455,12 @@ mod tests {
     }
 
     #[test]
-    fn install_cargo_toml() -> std::result::Result<(), Error> {
+    fn installercargo_toml() -> std::result::Result<(), Error> {
         let input = r#"
             [[jobs]]
             type = "installercargo"
             crates = [ "ssh-sensible" ]
-            state = "latest"
+            state = "present"
             "#;
 
         let got = Main::try_from(input)?;
@@ -456,7 +469,7 @@ mod tests {
             jobs: vec![Job {
                 spec: Spec::InstallerCargo(InstallerCargo {
                     crates: vec![String::from("ssh-sensible")],
-                    state: DesiredStateCargo::Latest,
+                    state: DesiredStateCargo::Present,
                     ..Default::default()
                 }),
                 ..Default::default()
@@ -472,7 +485,7 @@ mod tests {
     }
 
     #[test]
-    fn install_go_toml() -> std::result::Result<(), Error> {
+    fn installergo_toml() -> std::result::Result<(), Error> {
         let input = r#"
             [[jobs]]
             type = "installergo"
@@ -501,6 +514,36 @@ mod tests {
         Ok(())
     }
 
+    #[test]
+    fn installernpm_toml() -> std::result::Result<(), Error> {
+        let input = r#"
+            [[jobs]]
+            type = "installernpm"
+            packages = [ "open-cli" ]
+            state = "present"
+            "#;
+
+        let got = Main::try_from(input)?;
+
+        let want = Main {
+            jobs: vec![Job {
+                spec: Spec::InstallerNpm(InstallerNpm {
+                    packages: vec![String::from("open-cli")],
+                    state: DesiredStateNpm::Present,
+                    ..Default::default()
+                }),
+                ..Default::default()
+            }],
+        };
+
+        assert_eq!(got.jobs.len(), 1);
+        // TODO: find an approach that enables reliable `history` comparison
+        assert_eq!(got.jobs[0].metadata, want.jobs[0].metadata);
+        assert_eq!(got.jobs[0].spec, want.jobs[0].spec);
+
+        Ok(())
+    }
+
     #[test]
     fn absent_when_defaults_to_true() -> std::result::Result<(), Error> {
         let input = r#"
